/***********************************************************************************************************************************
Harness for Io Testing
***********************************************************************************************************************************/

/***********************************************************************************************************************************
Constants
***********************************************************************************************************************************/
// Arbitrary value for the shimmed socket file descriptor
#define HRN_SCK_FILE_DESCRIPTOR                                     1163581

/***********************************************************************************************************************************
Functions
***********************************************************************************************************************************/
// Install shim for sckClientOpenWait() to return false for an address one time
void hrnSckClientOpenWaitShimInstall(const char *address);

// Install/uninstall shim for clientOpen() to use a fake file descriptor
void hrnSckClientOpenShimInstall(void);
void hrnSckClientOpenShimUninstall(void);
